[Libreoffice-commits] core.git: 14 commits - compilerplugins/clang include/sfx2 include/svl include/svtools sfx2/source slideshow/source sot/source starmath/inc starmath/source svtools/source svx/source sw/source
Noel Grandin
noel.grandin at collabora.co.uk
Wed Feb 15 06:34:23 UTC 2017
compilerplugins/clang/unusedenumconstants.py | 4
include/sfx2/StylePreviewRenderer.hxx | 2
include/sfx2/objsh.hxx | 1
include/sfx2/shell.hxx | 5
include/svl/hint.hxx | 1
include/svtools/ivctrl.hxx | 14
sfx2/source/appl/workwin.cxx | 7
sfx2/source/doc/objxtor.cxx | 1
sfx2/source/inc/workwin.hxx | 4
slideshow/source/engine/animationfactory.cxx | 282 +++-----
slideshow/source/engine/animationnodes/animationbasenode.cxx | 4
slideshow/source/engine/animationnodes/animationnodefactory.cxx | 16
slideshow/source/engine/attributemap.cxx | 50 -
slideshow/source/engine/shapes/drawinglayeranimation.cxx | 6
slideshow/source/engine/shapes/drawshape.cxx | 9
slideshow/source/engine/shapes/drawshape.hxx | 3
slideshow/source/engine/shapes/drawshapesubsetting.cxx | 27
slideshow/source/engine/shapes/gdimtftools.cxx | 2
slideshow/source/engine/shapes/gdimtftools.hxx | 4
slideshow/source/engine/shapes/intrinsicanimationactivity.cxx | 51 -
slideshow/source/engine/shapes/intrinsicanimationactivity.hxx | 3
slideshow/source/engine/slide/slideimpl.cxx | 4
slideshow/source/engine/transitions/clippingfunctor.cxx | 22
slideshow/source/engine/transitions/transitionfactorytab.cxx | 336 +++++-----
slideshow/source/inc/attributemap.hxx | 49 -
slideshow/source/inc/doctreenode.hxx | 23
slideshow/source/inc/tools.hxx | 11
slideshow/source/inc/transitioninfo.hxx | 26
sot/source/sdstor/ucbstorage.cxx | 22
starmath/inc/cursor.hxx | 22
starmath/source/cursor.cxx | 71 --
starmath/source/view.cxx | 12
svtools/source/config/accessibilityoptions.cxx | 4
svtools/source/contnr/imivctl.hxx | 3
svtools/source/contnr/imivctl1.cxx | 32
svtools/source/contnr/ivctrl.cxx | 4
svx/source/styles/CommonStylePreviewRenderer.cxx | 5
sw/source/core/doc/DocumentLinksAdministrationManager.cxx | 2
sw/source/uibase/app/docsh.cxx | 1
sw/source/uibase/app/docshini.cxx | 1
sw/source/uibase/uiview/viewstat.cxx | 4
41 files changed, 464 insertions(+), 686 deletions(-)
New commits:
commit b17af4fa9ba59738818d1cd106e6066e6d1af3be
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date: Wed Feb 15 08:32:30 2017 +0200
remove unused PREVIEW from SfxObjectCreateMode enum
Change-Id: Idf930f768c978ac8aa53527f6ddb8864d0fdec1d
diff --git a/include/sfx2/objsh.hxx b/include/sfx2/objsh.hxx
index bd96409..9a42e24 100644
--- a/include/sfx2/objsh.hxx
+++ b/include/sfx2/objsh.hxx
@@ -177,7 +177,6 @@ enum class SfxObjectCreateMode
{
EMBEDDED,
STANDARD,
- PREVIEW,
ORGANIZER,
INTERNAL
};
diff --git a/sfx2/source/doc/objxtor.cxx b/sfx2/source/doc/objxtor.cxx
index 047719e..78b8126b 100644
--- a/sfx2/source/doc/objxtor.cxx
+++ b/sfx2/source/doc/objxtor.cxx
@@ -299,7 +299,6 @@ SfxObjectShell::SfxObjectShell( const SfxModelFlags i_nCreationFlags )
@param eMode Purpose, to which the SfxObjectShell is created:
SfxObjectCreateMode::EMBEDDED (default) as SO-Server from within another Document
SfxObjectCreateMode::STANDARD, as a normal Document open stand-alone
- SfxObjectCreateMode::PREVIEW to enable a Preview, if possible are only little information is needed
SfxObjectCreateMode::ORGANIZER to be displayed in the Organizer, here nothing of the contents is used
*/
SfxObjectShell::SfxObjectShell(SfxObjectCreateMode eMode)
diff --git a/sw/source/core/doc/DocumentLinksAdministrationManager.cxx b/sw/source/core/doc/DocumentLinksAdministrationManager.cxx
index 947e9f2..2494013 100644
--- a/sw/source/core/doc/DocumentLinksAdministrationManager.cxx
+++ b/sw/source/core/doc/DocumentLinksAdministrationManager.cxx
@@ -206,8 +206,6 @@ void DocumentLinksAdministrationManager::UpdateLinks()
return;
if (eMode == SfxObjectCreateMode::ORGANIZER)
return;
- if (eMode == SfxObjectCreateMode::PREVIEW)
- return;
if (m_rDoc.GetDocShell()->IsPreview())
return;
if (GetLinkManager().GetLinks().empty())
diff --git a/sw/source/uibase/app/docsh.cxx b/sw/source/uibase/app/docsh.cxx
index 5c2a814..2a94aa9 100644
--- a/sw/source/uibase/app/docsh.cxx
+++ b/sw/source/uibase/app/docsh.cxx
@@ -333,7 +333,6 @@ bool SwDocShell::Save()
SAL_FALLTHROUGH;
case SfxObjectCreateMode::STANDARD:
- case SfxObjectCreateMode::PREVIEW:
default:
{
if (m_pDoc->ContainsMSVBasic())
diff --git a/sw/source/uibase/app/docshini.cxx b/sw/source/uibase/app/docshini.cxx
index a547c94..1df546c 100644
--- a/sw/source/uibase/app/docshini.cxx
+++ b/sw/source/uibase/app/docshini.cxx
@@ -547,7 +547,6 @@ bool SwDocShell::Load( SfxMedium& rMedium )
SAL_FALLTHROUGH;
case SfxObjectCreateMode::STANDARD:
- case SfxObjectCreateMode::PREVIEW:
{
Reader *pReader = ReadXML;
if( pReader )
commit 1342a8a4f2fefa83bbf3a006efc6fb87702de618
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date: Tue Feb 14 16:20:50 2017 +0200
drop unused SwChildWindowMailmerge from SfxShellFeature enum
Change-Id: Ica64d75986877bc0b2fc3bafb092457396fb8e27
diff --git a/compilerplugins/clang/unusedenumconstants.py b/compilerplugins/clang/unusedenumconstants.py
index 81d4b08..e86bc13 100755
--- a/compilerplugins/clang/unusedenumconstants.py
+++ b/compilerplugins/clang/unusedenumconstants.py
@@ -126,6 +126,7 @@ for d in definitionSet:
"sw/inc/calc.hxx", # SwCalcOper
"svtools/source/config/helpopt.cxx", # HelpProperty
"include/svtools/htmltokn.h",
+ "include/sfx2/sidebar/Theme.hxx", # ThemeItem
# Windows or OSX only
"include/canvas/rendering/icolorbuffer.hxx",
"include/vcl/commandevent.hxx",
diff --git a/include/sfx2/shell.hxx b/include/sfx2/shell.hxx
index 4c7d12f..27eae63 100644
--- a/include/sfx2/shell.hxx
+++ b/include/sfx2/shell.hxx
@@ -99,7 +99,6 @@ enum class SfxShellFeature
NONE = 0x0000,
// Writer only, class SwView
SwChildWindowLabel = 0x0001,
- SwChildWindowMailmerge = 0x0002,
// Basic only, class Shell
BasicShowBrowser = 0x0004,
// Forms only, class FmFormShell
@@ -115,13 +114,13 @@ enum class SfxShellFeature
FormTBDesign = 0x1000,
FormShowDataNavigator = 0x2000,
// masks to make sure modules don't use flags from an other
- SwMask = 0x0003,
+ SwMask = 0x0001,
BasicMask = 0x0004,
FormMask = 0x3ff8
};
namespace o3tl
{
- template<> struct typed_flags<SfxShellFeature> : is_typed_flags<SfxShellFeature, 0x3fff> {};
+ template<> struct typed_flags<SfxShellFeature> : is_typed_flags<SfxShellFeature, 0x3ffd> {};
}
typedef void (*SfxExecFunc)(SfxShell *, SfxRequest &rReq);
diff --git a/sw/source/uibase/uiview/viewstat.cxx b/sw/source/uibase/uiview/viewstat.cxx
index 95b1688..3bbedcb 100644
--- a/sw/source/uibase/uiview/viewstat.cxx
+++ b/sw/source/uibase/uiview/viewstat.cxx
@@ -576,10 +576,6 @@ bool SwView::HasUIFeature(SfxShellFeature nFeature) const
{
case SfxShellFeature::SwChildWindowLabel:
return m_pWrtShell->IsLabelDoc();
-#if HAVE_FEATURE_DBCONNECTIVITY
- case SfxShellFeature::SwChildWindowMailmerge:
- return (nullptr != GetMailMergeConfigItem());
-#endif
default:
return false;
}
commit 3d60346febafbf37b7b19075f66ccf3c0255ab4f
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date: Tue Feb 14 16:03:22 2017 +0200
remove unused OBJECTBAR from SfxChildIdentifier enum
Change-Id: I45b02055d18ca201341c61a1558ee5b0c58d7ba8
diff --git a/sfx2/source/appl/workwin.cxx b/sfx2/source/appl/workwin.cxx
index 317b532..f961abb 100644
--- a/sfx2/source/appl/workwin.cxx
+++ b/sfx2/source/appl/workwin.cxx
@@ -1524,9 +1524,6 @@ void SfxWorkWindow::ConfigChild_Impl(SfxChildIdentifier eChild,
vcl::Window *pWin=nullptr;
SfxChildWin_Impl *pCW = nullptr;
- if ( eChild == SfxChildIdentifier::OBJECTBAR )
- return;
-
// configure direct childwindow
for (SfxChildWin_Impl* i : aChildWins)
{
diff --git a/sfx2/source/inc/workwin.hxx b/sfx2/source/inc/workwin.hxx
index e1aab80..a9a4fbe 100644
--- a/sfx2/source/inc/workwin.hxx
+++ b/sfx2/source/inc/workwin.hxx
@@ -133,7 +133,6 @@ struct SfxChildWin_Impl
enum class SfxChildIdentifier
{
- OBJECTBAR,
DOCKINGWINDOW,
SPLITWINDOW
};
commit 7f309cf37b97f7cc86b66c4c3ffe61b7563825d0
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date: Tue Feb 14 16:02:22 2017 +0200
remove unused MOVEDOCKINGWINDOW from SfxDockingConfig enum
Change-Id: I457596ed438b6c2173f25136bb8a99730b8f3a48
diff --git a/sfx2/source/appl/workwin.cxx b/sfx2/source/appl/workwin.cxx
index f0cdfc4..317b532 100644
--- a/sfx2/source/appl/workwin.cxx
+++ b/sfx2/source/appl/workwin.cxx
@@ -1698,7 +1698,6 @@ void SfxWorkWindow::ConfigChild_Impl(SfxChildIdentifier eChild,
break;
}
- case SfxDockingConfig::MOVEDOCKINGWINDOW :
case SfxDockingConfig::ALIGNDOCKINGWINDOW :
case SfxDockingConfig::TOGGLEFLOATMODE:
{
@@ -1736,8 +1735,7 @@ void SfxWorkWindow::ConfigChild_Impl(SfxChildIdentifier eChild,
SfxChildWindowFlags nFlags = pCW->aInfo.nFlags;
pCW->aInfo = pCW->pWin->GetInfo();
pCW->aInfo.nFlags |= nFlags;
- if ( eConfig != SfxDockingConfig::MOVEDOCKINGWINDOW )
- SaveStatus_Impl( pCW->pWin, pCW->aInfo);
+ SaveStatus_Impl( pCW->pWin, pCW->aInfo);
}
break;
diff --git a/sfx2/source/inc/workwin.hxx b/sfx2/source/inc/workwin.hxx
index d526ccd..e1aab80 100644
--- a/sfx2/source/inc/workwin.hxx
+++ b/sfx2/source/inc/workwin.hxx
@@ -142,8 +142,7 @@ enum class SfxDockingConfig
{
SETDOCKINGRECTS,
ALIGNDOCKINGWINDOW,
- TOGGLEFLOATMODE,
- MOVEDOCKINGWINDOW
+ TOGGLEFLOATMODE
};
commit 2a89b42e7daa69e44c96647297e0861987c84a49
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date: Tue Feb 14 15:58:33 2017 +0200
convert AttributeType to scoped enum
and drop unused CHAR_ROTATION enumerator
Change-Id: I9ca50aef41fa736c7f34c210844fb54f60f5bca8
diff --git a/slideshow/source/engine/animationfactory.cxx b/slideshow/source/engine/animationfactory.cxx
index c27f7d5..30449a9 100644
--- a/slideshow/source/engine/animationfactory.cxx
+++ b/slideshow/source/engine/animationfactory.cxx
@@ -734,56 +734,54 @@ namespace slideshow
{
default:
// FALLTHROUGH intended
- case ATTRIBUTE_INVALID:
+ case AttributeType::Invalid:
return CLASS_UNKNOWN_PROPERTY;
- case ATTRIBUTE_CHAR_COLOR:
+ case AttributeType::CharColor:
// FALLTHROUGH intended
- case ATTRIBUTE_COLOR:
+ case AttributeType::Color:
// FALLTHROUGH intended
- case ATTRIBUTE_DIMCOLOR:
+ case AttributeType::DimColor:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_COLOR:
+ case AttributeType::FillColor:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_COLOR:
+ case AttributeType::LineColor:
return CLASS_COLOR_PROPERTY;
- case ATTRIBUTE_CHAR_FONT_NAME:
+ case AttributeType::CharFontName:
return CLASS_STRING_PROPERTY;
- case ATTRIBUTE_VISIBILITY:
+ case AttributeType::Visibility:
return CLASS_BOOL_PROPERTY;
- case ATTRIBUTE_CHAR_HEIGHT:
+ case AttributeType::CharHeight:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_WEIGHT:
+ case AttributeType::CharWeight:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_ROTATION:
+ case AttributeType::Height:
// FALLTHROUGH intended
- case ATTRIBUTE_HEIGHT:
+ case AttributeType::Opacity:
// FALLTHROUGH intended
- case ATTRIBUTE_OPACITY:
+ case AttributeType::Rotate:
// FALLTHROUGH intended
- case ATTRIBUTE_ROTATE:
+ case AttributeType::SkewX:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_X:
+ case AttributeType::SkewY:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_Y:
+ case AttributeType::Width:
// FALLTHROUGH intended
- case ATTRIBUTE_WIDTH:
+ case AttributeType::PosX:
// FALLTHROUGH intended
- case ATTRIBUTE_POS_X:
- // FALLTHROUGH intended
- case ATTRIBUTE_POS_Y:
+ case AttributeType::PosY:
return CLASS_NUMBER_PROPERTY;
- case ATTRIBUTE_CHAR_UNDERLINE:
+ case AttributeType::CharUnderline:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_STYLE:
+ case AttributeType::FillStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_STYLE:
+ case AttributeType::LineStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_POSTURE:
+ case AttributeType::CharPosture:
return CLASS_ENUM_PROPERTY;
}
}
@@ -800,37 +798,37 @@ namespace slideshow
{
default:
// FALLTHROUGH intended
- case ATTRIBUTE_INVALID:
+ case AttributeType::Invalid:
ENSURE_OR_THROW( false,
"AnimationFactory::createNumberPropertyAnimation(): Unknown attribute" );
break;
- case ATTRIBUTE_CHAR_COLOR:
+ case AttributeType::CharColor:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_FONT_NAME:
+ case AttributeType::CharFontName:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_POSTURE:
+ case AttributeType::CharPosture:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_UNDERLINE:
+ case AttributeType::CharUnderline:
// FALLTHROUGH intended
- case ATTRIBUTE_COLOR:
+ case AttributeType::Color:
// FALLTHROUGH intended
- case ATTRIBUTE_DIMCOLOR:
+ case AttributeType::DimColor:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_COLOR:
+ case AttributeType::FillColor:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_STYLE:
+ case AttributeType::FillStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_COLOR:
+ case AttributeType::LineColor:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_STYLE:
+ case AttributeType::LineStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_VISIBILITY:
+ case AttributeType::Visibility:
ENSURE_OR_THROW( false,
"AnimationFactory::createNumberPropertyAnimation(): Attribute type mismatch" );
break;
- case ATTRIBUTE_CHAR_HEIGHT:
+ case AttributeType::CharHeight:
return makeGenericAnimation<NumberAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isCharScaleValid,
@@ -839,7 +837,7 @@ namespace slideshow
&ShapeAttributeLayer::getCharScale,
&ShapeAttributeLayer::setCharScale );
- case ATTRIBUTE_CHAR_WEIGHT:
+ case AttributeType::CharWeight:
return makeGenericAnimation<NumberAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isCharWeightValid,
@@ -847,15 +845,7 @@ namespace slideshow
&ShapeAttributeLayer::getCharWeight,
&ShapeAttributeLayer::setCharWeight );
- case ATTRIBUTE_CHAR_ROTATION:
- return makeGenericAnimation<NumberAnimation>( rShapeManager,
- nFlags,
- &ShapeAttributeLayer::isCharRotationAngleValid,
- getDefault<double>( rShape, rAttrName ),
- &ShapeAttributeLayer::getCharRotationAngle,
- &ShapeAttributeLayer::setCharRotationAngle );
-
- case ATTRIBUTE_HEIGHT:
+ case AttributeType::Height:
return makeGenericAnimation( rShapeManager,
nFlags,
&ShapeAttributeLayer::isHeightValid,
@@ -869,7 +859,7 @@ namespace slideshow
// convert expression parser value from relative page size
rSlideSize.getY() );
- case ATTRIBUTE_OPACITY:
+ case AttributeType::Opacity:
return makeGenericAnimation<NumberAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isAlphaValid,
@@ -878,7 +868,7 @@ namespace slideshow
&ShapeAttributeLayer::getAlpha,
&ShapeAttributeLayer::setAlpha );
- case ATTRIBUTE_ROTATE:
+ case AttributeType::Rotate:
return makeGenericAnimation<NumberAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isRotationAngleValid,
@@ -888,7 +878,7 @@ namespace slideshow
&ShapeAttributeLayer::getRotationAngle,
&ShapeAttributeLayer::setRotationAngle );
- case ATTRIBUTE_SKEW_X:
+ case AttributeType::SkewX:
return makeGenericAnimation<NumberAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isShearXAngleValid,
@@ -897,7 +887,7 @@ namespace slideshow
&ShapeAttributeLayer::getShearXAngle,
&ShapeAttributeLayer::setShearXAngle );
- case ATTRIBUTE_SKEW_Y:
+ case AttributeType::SkewY:
return makeGenericAnimation<NumberAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isShearYAngleValid,
@@ -906,7 +896,7 @@ namespace slideshow
&ShapeAttributeLayer::getShearYAngle,
&ShapeAttributeLayer::setShearYAngle );
- case ATTRIBUTE_WIDTH:
+ case AttributeType::Width:
return makeGenericAnimation( rShapeManager,
nFlags,
&ShapeAttributeLayer::isWidthValid,
@@ -920,7 +910,7 @@ namespace slideshow
// convert expression parser value from relative page size
rSlideSize.getX() );
- case ATTRIBUTE_POS_X:
+ case AttributeType::PosX:
return makeGenericAnimation( rShapeManager,
nFlags,
&ShapeAttributeLayer::isPosXValid,
@@ -934,7 +924,7 @@ namespace slideshow
// convert expression parser value from relative page size
rSlideSize.getX() );
- case ATTRIBUTE_POS_Y:
+ case AttributeType::PosY:
return makeGenericAnimation( rShapeManager,
nFlags,
&ShapeAttributeLayer::isPosYValid,
@@ -964,52 +954,50 @@ namespace slideshow
{
default:
// FALLTHROUGH intended
- case ATTRIBUTE_INVALID:
+ case AttributeType::Invalid:
ENSURE_OR_THROW( false,
"AnimationFactory::createEnumPropertyAnimation(): Unknown attribute" );
break;
- case ATTRIBUTE_CHAR_COLOR:
+ case AttributeType::CharColor:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_FONT_NAME:
+ case AttributeType::CharFontName:
// FALLTHROUGH intended
- case ATTRIBUTE_COLOR:
+ case AttributeType::Color:
// FALLTHROUGH intended
- case ATTRIBUTE_DIMCOLOR:
+ case AttributeType::DimColor:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_COLOR:
+ case AttributeType::FillColor:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_COLOR:
+ case AttributeType::LineColor:
// FALLTHROUGH intended
- case ATTRIBUTE_VISIBILITY:
+ case AttributeType::Visibility:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_HEIGHT:
+ case AttributeType::CharHeight:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_WEIGHT:
+ case AttributeType::CharWeight:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_ROTATION:
+ case AttributeType::Height:
// FALLTHROUGH intended
- case ATTRIBUTE_HEIGHT:
+ case AttributeType::Opacity:
// FALLTHROUGH intended
- case ATTRIBUTE_OPACITY:
+ case AttributeType::Rotate:
// FALLTHROUGH intended
- case ATTRIBUTE_ROTATE:
+ case AttributeType::SkewX:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_X:
+ case AttributeType::SkewY:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_Y:
+ case AttributeType::Width:
// FALLTHROUGH intended
- case ATTRIBUTE_WIDTH:
+ case AttributeType::PosX:
// FALLTHROUGH intended
- case ATTRIBUTE_POS_X:
- // FALLTHROUGH intended
- case ATTRIBUTE_POS_Y:
+ case AttributeType::PosY:
ENSURE_OR_THROW( false,
"AnimationFactory::createEnumPropertyAnimation(): Attribute type mismatch" );
break;
- case ATTRIBUTE_FILL_STYLE:
+ case AttributeType::FillStyle:
return makeGenericAnimation<EnumAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isFillStyleValid,
@@ -1018,7 +1006,7 @@ namespace slideshow
&ShapeAttributeLayer::getFillStyle,
&ShapeAttributeLayer::setFillStyle );
- case ATTRIBUTE_LINE_STYLE:
+ case AttributeType::LineStyle:
return makeGenericAnimation<EnumAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isLineStyleValid,
@@ -1027,7 +1015,7 @@ namespace slideshow
&ShapeAttributeLayer::getLineStyle,
&ShapeAttributeLayer::setLineStyle );
- case ATTRIBUTE_CHAR_POSTURE:
+ case AttributeType::CharPosture:
return makeGenericAnimation<EnumAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isCharPostureValid,
@@ -1036,7 +1024,7 @@ namespace slideshow
&ShapeAttributeLayer::getCharPosture,
&ShapeAttributeLayer::setCharPosture );
- case ATTRIBUTE_CHAR_UNDERLINE:
+ case AttributeType::CharUnderline:
return makeGenericAnimation<EnumAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isUnderlineModeValid,
@@ -1060,49 +1048,47 @@ namespace slideshow
{
default:
// FALLTHROUGH intended
- case ATTRIBUTE_INVALID:
+ case AttributeType::Invalid:
ENSURE_OR_THROW( false,
"AnimationFactory::createColorPropertyAnimation(): Unknown attribute" );
break;
- case ATTRIBUTE_CHAR_FONT_NAME:
- // FALLTHROUGH intended
- case ATTRIBUTE_CHAR_HEIGHT:
+ case AttributeType::CharFontName:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_POSTURE:
+ case AttributeType::CharHeight:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_ROTATION:
+ case AttributeType::CharPosture:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_UNDERLINE:
+ case AttributeType::CharUnderline:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_WEIGHT:
+ case AttributeType::CharWeight:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_STYLE:
+ case AttributeType::FillStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_HEIGHT:
+ case AttributeType::Height:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_STYLE:
+ case AttributeType::LineStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_OPACITY:
+ case AttributeType::Opacity:
// FALLTHROUGH intended
- case ATTRIBUTE_ROTATE:
+ case AttributeType::Rotate:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_X:
+ case AttributeType::SkewX:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_Y:
+ case AttributeType::SkewY:
// FALLTHROUGH intended
- case ATTRIBUTE_VISIBILITY:
+ case AttributeType::Visibility:
// FALLTHROUGH intended
- case ATTRIBUTE_WIDTH:
+ case AttributeType::Width:
// FALLTHROUGH intended
- case ATTRIBUTE_POS_X:
+ case AttributeType::PosX:
// FALLTHROUGH intended
- case ATTRIBUTE_POS_Y:
+ case AttributeType::PosY:
ENSURE_OR_THROW( false,
"AnimationFactory::createColorPropertyAnimation(): Attribute type mismatch" );
break;
- case ATTRIBUTE_CHAR_COLOR:
+ case AttributeType::CharColor:
return makeGenericAnimation<ColorAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isCharColorValid,
@@ -1110,7 +1096,7 @@ namespace slideshow
&ShapeAttributeLayer::getCharColor,
&ShapeAttributeLayer::setCharColor );
- case ATTRIBUTE_COLOR:
+ case AttributeType::Color:
// TODO(F2): This is just mapped to fill color to make it work
return makeGenericAnimation<ColorAnimation>( rShapeManager,
nFlags,
@@ -1119,7 +1105,7 @@ namespace slideshow
&ShapeAttributeLayer::getFillColor,
&ShapeAttributeLayer::setFillColor );
- case ATTRIBUTE_DIMCOLOR:
+ case AttributeType::DimColor:
return makeGenericAnimation<ColorAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isDimColorValid,
@@ -1127,7 +1113,7 @@ namespace slideshow
&ShapeAttributeLayer::getDimColor,
&ShapeAttributeLayer::setDimColor );
- case ATTRIBUTE_FILL_COLOR:
+ case AttributeType::FillColor:
return makeGenericAnimation<ColorAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isFillColorValid,
@@ -1135,7 +1121,7 @@ namespace slideshow
&ShapeAttributeLayer::getFillColor,
&ShapeAttributeLayer::setFillColor );
- case ATTRIBUTE_LINE_COLOR:
+ case AttributeType::LineColor:
return makeGenericAnimation<ColorAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isLineColorValid,
@@ -1212,57 +1198,55 @@ namespace slideshow
{
default:
// FALLTHROUGH intended
- case ATTRIBUTE_INVALID:
+ case AttributeType::Invalid:
ENSURE_OR_THROW( false,
"AnimationFactory::createStringPropertyAnimation(): Unknown attribute" );
break;
- case ATTRIBUTE_CHAR_COLOR:
+ case AttributeType::CharColor:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_HEIGHT:
+ case AttributeType::CharHeight:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_ROTATION:
+ case AttributeType::CharUnderline:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_UNDERLINE:
+ case AttributeType::Color:
// FALLTHROUGH intended
- case ATTRIBUTE_COLOR:
+ case AttributeType::DimColor:
// FALLTHROUGH intended
- case ATTRIBUTE_DIMCOLOR:
+ case AttributeType::FillColor:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_COLOR:
+ case AttributeType::Height:
// FALLTHROUGH intended
- case ATTRIBUTE_HEIGHT:
+ case AttributeType::LineColor:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_COLOR:
+ case AttributeType::Opacity:
// FALLTHROUGH intended
- case ATTRIBUTE_OPACITY:
+ case AttributeType::Rotate:
// FALLTHROUGH intended
- case ATTRIBUTE_ROTATE:
+ case AttributeType::SkewX:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_X:
+ case AttributeType::SkewY:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_Y:
+ case AttributeType::Visibility:
// FALLTHROUGH intended
- case ATTRIBUTE_VISIBILITY:
+ case AttributeType::Width:
// FALLTHROUGH intended
- case ATTRIBUTE_WIDTH:
+ case AttributeType::PosX:
// FALLTHROUGH intended
- case ATTRIBUTE_POS_X:
+ case AttributeType::PosY:
// FALLTHROUGH intended
- case ATTRIBUTE_POS_Y:
+ case AttributeType::CharPosture:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_POSTURE:
+ case AttributeType::CharWeight:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_WEIGHT:
+ case AttributeType::FillStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_STYLE:
- // FALLTHROUGH intended
- case ATTRIBUTE_LINE_STYLE:
+ case AttributeType::LineStyle:
ENSURE_OR_THROW( false,
"AnimationFactory::createStringPropertyAnimation(): Attribute type mismatch" );
break;
- case ATTRIBUTE_CHAR_FONT_NAME:
+ case AttributeType::CharFontName:
return makeGenericAnimation<StringAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isFontFamilyValid,
@@ -1286,57 +1270,55 @@ namespace slideshow
{
default:
// FALLTHROUGH intended
- case ATTRIBUTE_INVALID:
+ case AttributeType::Invalid:
ENSURE_OR_THROW( false,
"AnimationFactory::createBoolPropertyAnimation(): Unknown attribute" );
break;
- case ATTRIBUTE_CHAR_COLOR:
- // FALLTHROUGH intended
- case ATTRIBUTE_CHAR_FONT_NAME:
+ case AttributeType::CharColor:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_HEIGHT:
+ case AttributeType::CharFontName:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_POSTURE:
+ case AttributeType::CharHeight:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_ROTATION:
+ case AttributeType::CharPosture:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_WEIGHT:
+ case AttributeType::CharWeight:
// FALLTHROUGH intended
- case ATTRIBUTE_COLOR:
+ case AttributeType::Color:
// FALLTHROUGH intended
- case ATTRIBUTE_DIMCOLOR:
+ case AttributeType::DimColor:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_COLOR:
+ case AttributeType::FillColor:
// FALLTHROUGH intended
- case ATTRIBUTE_FILL_STYLE:
+ case AttributeType::FillStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_HEIGHT:
+ case AttributeType::Height:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_COLOR:
+ case AttributeType::LineColor:
// FALLTHROUGH intended
- case ATTRIBUTE_LINE_STYLE:
+ case AttributeType::LineStyle:
// FALLTHROUGH intended
- case ATTRIBUTE_OPACITY:
+ case AttributeType::Opacity:
// FALLTHROUGH intended
- case ATTRIBUTE_ROTATE:
+ case AttributeType::Rotate:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_X:
+ case AttributeType::SkewX:
// FALLTHROUGH intended
- case ATTRIBUTE_SKEW_Y:
+ case AttributeType::SkewY:
// FALLTHROUGH intended
- case ATTRIBUTE_WIDTH:
+ case AttributeType::Width:
// FALLTHROUGH intended
- case ATTRIBUTE_POS_X:
+ case AttributeType::PosX:
// FALLTHROUGH intended
- case ATTRIBUTE_POS_Y:
+ case AttributeType::PosY:
// FALLTHROUGH intended
- case ATTRIBUTE_CHAR_UNDERLINE:
+ case AttributeType::CharUnderline:
ENSURE_OR_THROW( false,
"AnimationFactory::createBoolPropertyAnimation(): Attribute type mismatch" );
break;
- case ATTRIBUTE_VISIBILITY:
+ case AttributeType::Visibility:
return makeGenericAnimation<BoolAnimation>( rShapeManager,
nFlags,
&ShapeAttributeLayer::isVisibilityValid,
diff --git a/slideshow/source/engine/attributemap.cxx b/slideshow/source/engine/attributemap.cxx
index 200bcdc..0257094 100644
--- a/slideshow/source/engine/attributemap.cxx
+++ b/slideshow/source/engine/attributemap.cxx
@@ -41,44 +41,44 @@ namespace slideshow
*/
static const AnimateAttributeMap::MapEntry lcl_attributeMap[] =
{
- { "charcolor", ATTRIBUTE_CHAR_COLOR },
- { "charfontname", ATTRIBUTE_CHAR_FONT_NAME },
- { "charheight", ATTRIBUTE_CHAR_HEIGHT },
- { "charposture", ATTRIBUTE_CHAR_POSTURE },
+ { "charcolor", AttributeType::CharColor },
+ { "charfontname", AttributeType::CharFontName },
+ { "charheight", AttributeType::CharHeight },
+ { "charposture", AttributeType::CharPosture },
// TODO(Q1): This should prolly be changed in PPT import
- // { "charrotation", ATTRIBUTE_CHAR_ROTATION },
- { "charrotation", ATTRIBUTE_ROTATE },
- { "charunderline", ATTRIBUTE_CHAR_UNDERLINE },
- { "charweight", ATTRIBUTE_CHAR_WEIGHT },
- { "color", ATTRIBUTE_COLOR },
- { "dimcolor", ATTRIBUTE_DIMCOLOR },
- { "fillcolor", ATTRIBUTE_FILL_COLOR },
- { "fillstyle", ATTRIBUTE_FILL_STYLE },
- { "height", ATTRIBUTE_HEIGHT },
- { "linecolor", ATTRIBUTE_LINE_COLOR },
- { "linestyle", ATTRIBUTE_LINE_STYLE },
- { "opacity", ATTRIBUTE_OPACITY },
- { "rotate", ATTRIBUTE_ROTATE },
- { "skewx", ATTRIBUTE_SKEW_X },
- { "skewy", ATTRIBUTE_SKEW_Y },
- { "visibility", ATTRIBUTE_VISIBILITY },
- { "width", ATTRIBUTE_WIDTH },
- { "x", ATTRIBUTE_POS_X },
- { "y", ATTRIBUTE_POS_Y }
+ // { "charrotation", AttributeType::CharRotation },
+ { "charrotation", AttributeType::Rotate },
+ { "charunderline", AttributeType::CharUnderline },
+ { "charweight", AttributeType::CharWeight },
+ { "color", AttributeType::Color },
+ { "dimcolor", AttributeType::DimColor },
+ { "fillcolor", AttributeType::FillColor },
+ { "fillstyle", AttributeType::FillStyle },
+ { "height", AttributeType::Height },
+ { "linecolor", AttributeType::LineColor },
+ { "linestyle", AttributeType::LineStyle },
+ { "opacity", AttributeType::Opacity },
+ { "rotate", AttributeType::Rotate },
+ { "skewx", AttributeType::SkewX },
+ { "skewy", AttributeType::SkewY },
+ { "visibility", AttributeType::Visibility },
+ { "width", AttributeType::Width },
+ { "x", AttributeType::PosX },
+ { "y", AttributeType::PosY }
};
static const AnimateAttributeMap aMap( lcl_attributeMap,
SAL_N_ELEMENTS(lcl_attributeMap),
false );
- AttributeType eAttributeType = ATTRIBUTE_INVALID;
+ AttributeType eAttributeType = AttributeType::Invalid;
// determine the type from the attribute name
if( !aMap.lookup( rAttrName,
eAttributeType ) )
{
SAL_WARN("slideshow", "mapAttributeName(): attribute name not found in map: " << rAttrName);
- return ATTRIBUTE_INVALID;
+ return AttributeType::Invalid;
}
return eAttributeType;
diff --git a/slideshow/source/inc/attributemap.hxx b/slideshow/source/inc/attributemap.hxx
index 74299e0..6ab9c24e 100644
--- a/slideshow/source/inc/attributemap.hxx
+++ b/slideshow/source/inc/attributemap.hxx
@@ -33,36 +33,35 @@ namespace slideshow
This enum describes the type of an animated
attribute.
*/
- enum AttributeType
+ enum class AttributeType
{
- ATTRIBUTE_INVALID,
- ATTRIBUTE_CHAR_COLOR,
- ATTRIBUTE_CHAR_FONT_NAME,
- ATTRIBUTE_CHAR_HEIGHT,
- ATTRIBUTE_CHAR_POSTURE,
- ATTRIBUTE_CHAR_ROTATION,
- ATTRIBUTE_CHAR_UNDERLINE,
- ATTRIBUTE_CHAR_WEIGHT,
- ATTRIBUTE_COLOR,
- ATTRIBUTE_DIMCOLOR,
- ATTRIBUTE_FILL_COLOR,
- ATTRIBUTE_FILL_STYLE,
- ATTRIBUTE_HEIGHT,
- ATTRIBUTE_LINE_COLOR,
- ATTRIBUTE_LINE_STYLE,
- ATTRIBUTE_OPACITY,
- ATTRIBUTE_ROTATE,
- ATTRIBUTE_SKEW_X,
- ATTRIBUTE_SKEW_Y,
- ATTRIBUTE_VISIBILITY,
- ATTRIBUTE_WIDTH,
- ATTRIBUTE_POS_X,
- ATTRIBUTE_POS_Y
+ Invalid,
+ CharColor,
+ CharFontName,
+ CharHeight,
+ CharPosture,
+ CharUnderline,
+ CharWeight,
+ Color,
+ DimColor,
+ FillColor,
+ FillStyle,
+ Height,
+ LineColor,
+ LineStyle,
+ Opacity,
+ Rotate,
+ SkewX,
+ SkewY,
+ Visibility,
+ Width,
+ PosX,
+ PosY
};
/** Map attribute name to AttributeType enum
- @returns ATTRIBUTE_INVALID, if name was not found in the
+ @returns AttributeType::Invalid, if name was not found in the
mapping table.
*/
AttributeType mapAttributeName( const OUString& rAttrName );
commit 0102b85e4e2506299e034e623b75f9400450eb90
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date: Tue Feb 14 15:52:53 2017 +0200
convert DocTreeNode::NodeType to scoped enum
and drop unused enumerators
Change-Id: I0b9220cc2a70847ee43b63accec5bede3dbb99fa
diff --git a/slideshow/source/engine/animationnodes/animationbasenode.cxx b/slideshow/source/engine/animationnodes/animationbasenode.cxx
index fbd9bb8..c25cdf5 100644
--- a/slideshow/source/engine/animationnodes/animationbasenode.cxx
+++ b/slideshow/source/engine/animationnodes/animationbasenode.cxx
@@ -131,12 +131,12 @@ AnimationBaseNode::AnimationBaseNode(
// provide the given paragraph?
if( aTarget.Paragraph >= 0 &&
mpShape->getTreeNodeSupplier().getNumberOfTreeNodes(
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH) > aTarget.Paragraph )
+ DocTreeNode::NodeType::LogicalParagraph) > aTarget.Paragraph )
{
const DocTreeNode& rTreeNode(
mpShape->getTreeNodeSupplier().getTreeNode(
aTarget.Paragraph,
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ) );
+ DocTreeNode::NodeType::LogicalParagraph ) );
// CAUTION: the creation of the subset shape
// _must_ stay in the node constructor, since
diff --git a/slideshow/source/engine/animationnodes/animationnodefactory.cxx b/slideshow/source/engine/animationnodes/animationnodefactory.cxx
index 9881e63..94ee2e1 100644
--- a/slideshow/source/engine/animationnodes/animationnodefactory.cxx
+++ b/slideshow/source/engine/animationnodes/animationnodefactory.cxx
@@ -239,7 +239,7 @@ bool implCreateIteratedNodes(
ENSURE_OR_RETURN_FALSE(
aTarget.Paragraph >= 0 &&
rTreeNodeSupplier.getNumberOfTreeNodes(
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ) > aTarget.Paragraph,
+ DocTreeNode::NodeType::LogicalParagraph ) > aTarget.Paragraph,
"implCreateIteratedNodes(): paragraph index out of range" );
pTargetSubset.reset(
@@ -249,7 +249,7 @@ bool implCreateIteratedNodes(
// type PARAGRAPH from this shape
rTreeNodeSupplier.getTreeNode(
aTarget.Paragraph,
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ),
+ DocTreeNode::NodeType::LogicalParagraph ),
rContext.maContext.mpSubsettableShapeManager ) );
// iterate target is not the whole shape, but only
@@ -325,20 +325,20 @@ bool implCreateIteratedNodes(
// determine type of subitem iteration (logical
// text unit to animate)
DocTreeNode::NodeType eIterateNodeType(
- DocTreeNode::NODETYPE_LOGICAL_CHARACTER_CELL );
+ DocTreeNode::NodeType::LogicalCharacterCell );
switch( xIterNode->getIterateType() )
{
case presentation::TextAnimationType::BY_PARAGRAPH:
- eIterateNodeType = DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH;
+ eIterateNodeType = DocTreeNode::NodeType::LogicalParagraph;
break;
case presentation::TextAnimationType::BY_WORD:
- eIterateNodeType = DocTreeNode::NODETYPE_LOGICAL_WORD;
+ eIterateNodeType = DocTreeNode::NodeType::LogicalWord;
break;
case presentation::TextAnimationType::BY_LETTER:
- eIterateNodeType = DocTreeNode::NODETYPE_LOGICAL_CHARACTER_CELL;
+ eIterateNodeType = DocTreeNode::NodeType::LogicalCharacterCell;
break;
default:
@@ -349,8 +349,8 @@ bool implCreateIteratedNodes(
}
if( bParagraphTarget &&
- eIterateNodeType != DocTreeNode::NODETYPE_LOGICAL_WORD &&
- eIterateNodeType != DocTreeNode::NODETYPE_LOGICAL_CHARACTER_CELL )
+ eIterateNodeType != DocTreeNode::NodeType::LogicalWord &&
+ eIterateNodeType != DocTreeNode::NodeType::LogicalCharacterCell )
{
// will not animate the whole paragraph, when
// only the paragraph is animated at all.
diff --git a/slideshow/source/engine/shapes/drawinglayeranimation.cxx b/slideshow/source/engine/shapes/drawinglayeranimation.cxx
index 0ca3695..e82072d 100644
--- a/slideshow/source/engine/shapes/drawinglayeranimation.cxx
+++ b/slideshow/source/engine/shapes/drawinglayeranimation.cxx
@@ -738,17 +738,17 @@ ActivityImpl::ActivityImpl(
{
// get doctreenode:
sal_Int32 const nNodes = pParentDrawShape->getNumberOfTreeNodes(
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH );
+ DocTreeNode::NodeType::LogicalParagraph );
DocTreeNode scrollTextNode(
pParentDrawShape->getTreeNode(
- 0, DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ));
+ 0, DocTreeNode::NodeType::LogicalParagraph ));
// xxx todo: remove this hack
if( nNodes > 1 )
scrollTextNode.setEndIndex(
pParentDrawShape->getTreeNode(
nNodes - 1,
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ).getEndIndex());
+ DocTreeNode::NodeType::LogicalParagraph ).getEndIndex());
// TODO(Q3): Doing this manually, instead of using
// ShapeSubset. This is because of lifetime issues (ShapeSubset
diff --git a/slideshow/source/engine/shapes/drawshape.cxx b/slideshow/source/engine/shapes/drawshape.cxx
index 8ee2dc7..143786a 100644
--- a/slideshow/source/engine/shapes/drawshape.cxx
+++ b/slideshow/source/engine/shapes/drawshape.cxx
@@ -527,7 +527,7 @@ namespace slideshow
{
OSL_ASSERT( pShape->maAnimationFrames.empty() );
if( pShape->getNumberOfTreeNodes(
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH) > 0 )
+ DocTreeNode::NodeType::LogicalParagraph) > 0 )
{
pShape->mpIntrinsicAnimationActivity =
createDrawingLayerAnimActivity(
diff --git a/slideshow/source/engine/shapes/drawshapesubsetting.cxx b/slideshow/source/engine/shapes/drawshapesubsetting.cxx
index d8a1ad1..dccca64 100644
--- a/slideshow/source/engine/shapes/drawshapesubsetting.cxx
+++ b/slideshow/source/engine/shapes/drawshapesubsetting.cxx
@@ -187,10 +187,10 @@ namespace slideshow
// that subtract from it
maCurrentSubsets.push_back( DocTreeNode( 0,
mnMinSubsetActionIndex,
- DocTreeNode::NODETYPE_INVALID ) );
+ DocTreeNode::NodeType::Invalid ) );
maCurrentSubsets.push_back( DocTreeNode( mnMaxSubsetActionIndex,
maActionClassVector.size(),
- DocTreeNode::NODETYPE_INVALID ) );
+ DocTreeNode::NodeType::Invalid ) );
}
else
{
@@ -198,10 +198,10 @@ namespace slideshow
// subsets subtract content
maCurrentSubsets.push_back( DocTreeNode( maSubset.getStartIndex(),
mnMinSubsetActionIndex,
- DocTreeNode::NODETYPE_INVALID ) );
+ DocTreeNode::NodeType::Invalid ) );
maCurrentSubsets.push_back( DocTreeNode( mnMaxSubsetActionIndex,
maSubset.getEndIndex(),
- DocTreeNode::NODETYPE_INVALID ) );
+ DocTreeNode::NodeType::Invalid ) );
}
}
else
@@ -590,30 +590,19 @@ namespace slideshow
{
switch( eNodeType )
{
- case DocTreeNode::NODETYPE_INVALID:
+ case DocTreeNode::NodeType::Invalid:
// FALLTHROUGH intended
default:
SAL_WARN( "slideshow", "DrawShapeSubsetting::mapDocTreeNode(): unexpected node type");
return DrawShapeSubsetting::CLASS_NOOP;
- case DocTreeNode::NODETYPE_LOGICAL_SHAPE:
- // FALLTHROUGH intended
- case DocTreeNode::NODETYPE_FORMATTING_SHAPE:
- return DrawShapeSubsetting::CLASS_SHAPE_END;
-
- case DocTreeNode::NODETYPE_FORMATTING_LINE:
- return DrawShapeSubsetting::CLASS_LINE_END;
-
- case DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH:
+ case DocTreeNode::NodeType::LogicalParagraph:
return DrawShapeSubsetting::CLASS_PARAGRAPH_END;
- case DocTreeNode::NODETYPE_LOGICAL_SENTENCE:
- return DrawShapeSubsetting::CLASS_SENTENCE_END;
-
- case DocTreeNode::NODETYPE_LOGICAL_WORD:
+ case DocTreeNode::NodeType::LogicalWord:
return DrawShapeSubsetting::CLASS_WORD_END;
- case DocTreeNode::NODETYPE_LOGICAL_CHARACTER_CELL:
+ case DocTreeNode::NodeType::LogicalCharacterCell:
return DrawShapeSubsetting::CLASS_CHARACTER_CELL_END;
};
}
diff --git a/slideshow/source/engine/slide/slideimpl.cxx b/slideshow/source/engine/slide/slideimpl.cxx
index 49e1aba..a5ed1e2 100644
--- a/slideshow/source/engine/slide/slideimpl.cxx
+++ b/slideshow/source/engine/slide/slideimpl.cxx
@@ -905,7 +905,7 @@ void SlideImpl::applyShapeAttributes(
const DocTreeNodeSupplier& rNodeSupplier( pAttrShape->getTreeNodeSupplier() );
if( rNodeSupplier.getNumberOfTreeNodes(
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ) <= nParaIndex )
+ DocTreeNode::NodeType::LogicalParagraph ) <= nParaIndex )
{
OSL_FAIL( "SlideImpl::applyInitialShapeAttributes(): shape found does not "
"provide a subset for requested paragraph index" );
@@ -915,7 +915,7 @@ void SlideImpl::applyShapeAttributes(
pAttrShape = pAttrShape->getSubset(
rNodeSupplier.getTreeNode(
nParaIndex,
- DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ) );
+ DocTreeNode::NodeType::LogicalParagraph ) );
if( !pAttrShape )
{
diff --git a/slideshow/source/inc/doctreenode.hxx b/slideshow/source/inc/doctreenode.hxx
index 584832c..f619a4b 100644
--- a/slideshow/source/inc/doctreenode.hxx
+++ b/slideshow/source/inc/doctreenode.hxx
@@ -47,25 +47,16 @@ namespace slideshow
{
public:
/// Type of shape entity represented by this node
- enum NodeType
+ enum class NodeType
{
- NODETYPE_INVALID=0,
+ Invalid=0,
- /// This node represents a full shape
- NODETYPE_FORMATTING_SHAPE=1,
- /// This node represents a line
- NODETYPE_FORMATTING_LINE=2,
-
- /// This node represents a full shape
- NODETYPE_LOGICAL_SHAPE=128,
/// This node represents a paragraph
- NODETYPE_LOGICAL_PARAGRAPH=129,
- /// This node represents a sentence
- NODETYPE_LOGICAL_SENTENCE=130,
+ LogicalParagraph=129,
/// This node represents a word
- NODETYPE_LOGICAL_WORD=131,
+ LogicalWord=131,
/// This node represents a character
- NODETYPE_LOGICAL_CHARACTER_CELL=132
+ LogicalCharacterCell=132
};
/** Create empty tree node
@@ -73,7 +64,7 @@ namespace slideshow
DocTreeNode() :
mnStartIndex(-1),
mnEndIndex(-1),
- meType(NODETYPE_INVALID)
+ meType(NodeType::Invalid)
{
}
@@ -109,7 +100,7 @@ namespace slideshow
{
mnStartIndex = -1;
mnEndIndex = -1;
- meType = NODETYPE_INVALID;
+ meType = NodeType::Invalid;
}
private:
commit 602a07e110df440a02692b607b6fc08ddfb074d5
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date: Tue Feb 14 15:47:01 2017 +0200
drop CycleMode enum
since we only ever used the CYCLE_LOOP enumerator
Change-Id: I181be1e1bba7f72f64420ab22e119d2bffad2d37
diff --git a/slideshow/source/engine/shapes/drawshape.cxx b/slideshow/source/engine/shapes/drawshape.cxx
index 6bbdc53..8ee2dc7 100644
--- a/slideshow/source/engine/shapes/drawshape.cxx
+++ b/slideshow/source/engine/shapes/drawshape.cxx
@@ -383,7 +383,6 @@ namespace slideshow
maSubsetting(),
mnIsAnimatedCount(0),
mnAnimationLoopCount(0),
- meCycleMode(CYCLE_LOOP),
mbIsVisible( true ),
mbForceUpdate( false ),
mbAttributeLayerRevoked( false ),
@@ -443,7 +442,6 @@ namespace slideshow
maSubsetting(),
mnIsAnimatedCount(0),
mnAnimationLoopCount(0),
- meCycleMode(CYCLE_LOOP),
mbIsVisible( true ),
mbForceUpdate( false ),
mbAttributeLayerRevoked( false ),
@@ -454,7 +452,6 @@ namespace slideshow
getAnimationFromGraphic( maAnimationFrames,
mnAnimationLoopCount,
- meCycleMode,
rGraphic );
ENSURE_OR_THROW( !maAnimationFrames.empty() &&
@@ -495,7 +492,6 @@ namespace slideshow
maSubsetting( rTreeNode, mpCurrMtf ),
mnIsAnimatedCount(0),
mnAnimationLoopCount(0),
- meCycleMode(CYCLE_LOOP),
mbIsVisible( rSrc.mbIsVisible ),
mbForceUpdate( false ),
mbAttributeLayerRevoked( false ),
@@ -580,8 +576,7 @@ namespace slideshow
pShape,
pWakeupEvent,
aTimeout,
- pShape->mnAnimationLoopCount,
- pShape->meCycleMode);
+ pShape->mnAnimationLoopCount);
pWakeupEvent->setActivity( pActivity );
pShape->mpIntrinsicAnimationActivity = pActivity;
diff --git a/slideshow/source/engine/shapes/drawshape.hxx b/slideshow/source/engine/shapes/drawshape.hxx
index 5db8b11..51dfcff 100644
--- a/slideshow/source/engine/shapes/drawshape.hxx
+++ b/slideshow/source/engine/shapes/drawshape.hxx
@@ -339,9 +339,6 @@ namespace slideshow
/// Number of times the bitmap animation shall loop
::std::size_t mnAnimationLoopCount;
- /// Cycle mode for bitmap animation
- CycleMode meCycleMode;
-
/// Whether shape is visible (without attribute layers)
bool mbIsVisible;
diff --git a/slideshow/source/engine/shapes/gdimtftools.cxx b/slideshow/source/engine/shapes/gdimtftools.cxx
index 3869562..fdd383f 100644
--- a/slideshow/source/engine/shapes/gdimtftools.cxx
+++ b/slideshow/source/engine/shapes/gdimtftools.cxx
@@ -264,7 +264,6 @@ sal_Int32 getNextActionOffset( MetaAction * pCurrAct )
bool getAnimationFromGraphic( VectorOfMtfAnimationFrames& o_rFrames,
::std::size_t& o_rLoopCount,
- CycleMode& o_eCycleMode,
const Graphic& rGraphic )
{
o_rFrames.clear();
@@ -291,7 +290,6 @@ bool getAnimationFromGraphic( VectorOfMtfAnimationFrames& o_rFrames,
pVDevMask->EnableMapMode( false );
o_rLoopCount = aAnimation.GetLoopCount();
- o_eCycleMode = CYCLE_LOOP;
for( sal_uInt16 i=0, nCount=aAnimation.Count(); i<nCount; ++i )
{
diff --git a/slideshow/source/engine/shapes/gdimtftools.hxx b/slideshow/source/engine/shapes/gdimtftools.hxx
index d27e6ed..861d352 100644
--- a/slideshow/source/engine/shapes/gdimtftools.hxx
+++ b/slideshow/source/engine/shapes/gdimtftools.hxx
@@ -109,15 +109,11 @@ namespace slideshow
@param o_rLoopCount
Number of times the bitmap animation shall be repeated
- @param o_eCycleMode
- Repeat mode (normal, or ping-pong mode)
-
@param rGraphic
Input graphic object, to extract animations from
*/
bool getAnimationFromGraphic( VectorOfMtfAnimationFrames& o_rFrames,
::std::size_t& o_rLoopCount,
- CycleMode& o_eCycleMode,
const Graphic& rGraphic );
/** Retrieve scroll text animation rectangles from given metafile
diff --git a/slideshow/source/engine/shapes/intrinsicanimationactivity.cxx b/slideshow/source/engine/shapes/intrinsicanimationactivity.cxx
index ba1d481..e44f832 100644
--- a/slideshow/source/engine/shapes/intrinsicanimationactivity.cxx
+++ b/slideshow/source/engine/shapes/intrinsicanimationactivity.cxx
@@ -65,8 +65,7 @@ namespace slideshow
const DrawShapeSharedPtr& rDrawShape,
const WakeupEventSharedPtr& rWakeupEvent,
const ::std::vector<double>& rTimeouts,
- ::std::size_t nNumLoops,
- CycleMode eCycleMode );
+ ::std::size_t nNumLoops );
IntrinsicAnimationActivity(const IntrinsicAnimationActivity&) = delete;
IntrinsicAnimationActivity& operator=(const IntrinsicAnimationActivity&) = delete;
@@ -85,7 +84,6 @@ namespace slideshow
WakeupEventSharedPtr mpWakeupEvent;
IntrinsicAnimationEventHandlerSharedPtr mpListener;
::std::vector<double> maTimeouts;
- CycleMode meCycleMode;
::std::size_t mnCurrIndex;
::std::size_t mnNumLoops;
::std::size_t mnLoopCount;
@@ -115,14 +113,12 @@ namespace slideshow
const DrawShapeSharedPtr& rDrawShape,
const WakeupEventSharedPtr& rWakeupEvent,
const ::std::vector<double>& rTimeouts,
- ::std::size_t nNumLoops,
- CycleMode eCycleMode ) :
+ ::std::size_t nNumLoops ) :
maContext( rContext ),
mpDrawShape( rDrawShape ),
mpWakeupEvent( rWakeupEvent ),
mpListener( new IntrinsicAnimationListener(*this) ),
maTimeouts( rTimeouts ),
- meCycleMode( eCycleMode ),
mnCurrIndex(0),
mnNumLoops(nNumLoops),
mnLoopCount(0),
@@ -192,35 +188,14 @@ namespace slideshow
::std::size_t nNewIndex = 0;
const ::std::size_t nNumFrames(maTimeouts.size());
- switch( meCycleMode )
- {
- case CYCLE_LOOP:
- {
- pDrawShape->setIntrinsicAnimationFrame( mnCurrIndex );
-
- mpWakeupEvent->start();
- mpWakeupEvent->setNextTimeout( maTimeouts[mnCurrIndex] );
-
- mnLoopCount += (mnCurrIndex + 1) / nNumFrames;
- nNewIndex = (mnCurrIndex + 1) % nNumFrames;
- break;
- }
-
- case CYCLE_PINGPONGLOOP:
- {
- ::std::size_t nTrueIndex( mnCurrIndex < nNumFrames ?
- mnCurrIndex :
- 2*nNumFrames - mnCurrIndex - 1 );
- pDrawShape->setIntrinsicAnimationFrame( nTrueIndex );
-
- mpWakeupEvent->start();
- mpWakeupEvent->setNextTimeout( maTimeouts[nTrueIndex] );
-
- mnLoopCount += (mnCurrIndex + 1) / (2*nNumFrames);
- nNewIndex = (mnCurrIndex + 1) % 2*nNumFrames;
- break;
- }
- }
+
+ pDrawShape->setIntrinsicAnimationFrame( mnCurrIndex );
+
+ mpWakeupEvent->start();
+ mpWakeupEvent->setNextTimeout( maTimeouts[mnCurrIndex] );
+
+ mnLoopCount += (mnCurrIndex + 1) / nNumFrames;
+ nNewIndex = (mnCurrIndex + 1) % nNumFrames;
maContext.mrEventQueue.addEvent( mpWakeupEvent );
maContext.mpSubsettableShapeManager->notifyShapeUpdate( pDrawShape );
@@ -259,16 +234,14 @@ namespace slideshow
const DrawShapeSharedPtr& rDrawShape,
const WakeupEventSharedPtr& rWakeupEvent,
const ::std::vector<double>& rTimeouts,
- ::std::size_t nNumLoops,
- CycleMode eCycleMode )
+ ::std::size_t nNumLoops )
{
return ActivitySharedPtr(
new IntrinsicAnimationActivity(rContext,
rDrawShape,
rWakeupEvent,
rTimeouts,
- nNumLoops,
- eCycleMode) );
+ nNumLoops) );
}
}
}
diff --git a/slideshow/source/engine/shapes/intrinsicanimationactivity.hxx b/slideshow/source/engine/shapes/intrinsicanimationactivity.hxx
index 54e2772..628a458 100644
--- a/slideshow/source/engine/shapes/intrinsicanimationactivity.hxx
+++ b/slideshow/source/engine/shapes/intrinsicanimationactivity.hxx
@@ -60,8 +60,7 @@ namespace slideshow
const DrawShapeSharedPtr& rDrawShape,
const WakeupEventSharedPtr& rWakeupEvent,
const ::std::vector<double>& rTimeouts,
- ::std::size_t nNumLoops,
- CycleMode eCycleMode );
+ ::std::size_t nNumLoops );
}
}
diff --git a/slideshow/source/inc/tools.hxx b/slideshow/source/inc/tools.hxx
index d1165a6..0b83377 100644
--- a/slideshow/source/inc/tools.hxx
+++ b/slideshow/source/inc/tools.hxx
@@ -105,17 +105,6 @@ namespace slideshow
{
namespace internal
{
- /** Cycle mode of intrinsic animations
- */
- enum CycleMode
- {
- /// loop the animation back to back
- CYCLE_LOOP,
- /// loop, but play backwards from end to start
- CYCLE_PINGPONGLOOP
- };
-
-
// Value extraction from Any
// =========================
commit dd803c6e2551ed3f49d2275f7020e4987773adb6
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date: Tue Feb 14 15:42:53 2017 +0200
convert ReverseMethod to scoped enum
and drop unused enumerators
REVERSEMETHOD_INVERT_SWEEP
REVERSEMETHOD_SUBTRACT_POLYGON
Change-Id: I11b52d4b32e5f766dfa3bcd69b9c636f4106b7b4
diff --git a/slideshow/source/engine/transitions/transitionfactorytab.cxx b/slideshow/source/engine/transitions/transitionfactorytab.cxx
index 021c359..760d2a7 100644
--- a/slideshow/source/engine/transitions/transitionfactorytab.cxx
+++ b/slideshow/source/engine/transitions/transitionfactorytab.cxx
@@ -44,7 +44,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0,
0.0,
0.0,
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
false,
false
},
@@ -56,7 +56,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
false, // 'out' by subtraction
false // scale isotrophically to target size
},
@@ -68,7 +68,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_Y,
+ TransitionInfo::ReverseMethod::FlipY,
false, // 'out' by subtraction
false // scale isotrophically to target size
},
@@ -81,7 +81,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_Y,
+ TransitionInfo::ReverseMethod::FlipY,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -93,7 +93,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -106,7 +106,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE, // possible via bottomRight
+ TransitionInfo::ReverseMethod::Ignore, // possible via bottomRight
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -118,7 +118,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE, // possible via bottomLeft
+ TransitionInfo::ReverseMethod::Ignore, // possible via bottomLeft
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -130,7 +130,7 @@ static const TransitionInfo lcl_transitionInfo[] =
180.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE, // possible via topLeft
+ TransitionInfo::ReverseMethod::Ignore, // possible via topLeft
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -142,7 +142,7 @@ static const TransitionInfo lcl_transitionInfo[] =
-90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE, // possible via topRight
+ TransitionInfo::ReverseMethod::Ignore, // possible via topRight
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -154,7 +154,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_Y,
+ TransitionInfo::ReverseMethod::FlipY,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -166,7 +166,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -178,7 +178,7 @@ static const TransitionInfo lcl_transitionInfo[] =
180.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_Y,
+ TransitionInfo::ReverseMethod::FlipY,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -190,7 +190,7 @@ static const TransitionInfo lcl_transitionInfo[] =
-90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -203,7 +203,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -215,7 +215,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -228,7 +228,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -240,7 +240,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -252,7 +252,7 @@ static const TransitionInfo lcl_transitionInfo[] =
45.0, // rotation
M_SQRT2, // scaling
M_SQRT2, // scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -264,7 +264,7 @@ static const TransitionInfo lcl_transitionInfo[] =
-45.0, // rotation
M_SQRT2, // scaling
M_SQRT2, // scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -277,7 +277,7 @@ static const TransitionInfo lcl_transitionInfo[] =
45.0, // rotation
M_SQRT2, // scaling
M_SQRT2, // scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -289,7 +289,7 @@ static const TransitionInfo lcl_transitionInfo[] =
135.0, // rotation
M_SQRT2, // scaling
M_SQRT2, // scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -303,7 +303,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -315,7 +315,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -328,7 +328,7 @@ static const TransitionInfo lcl_transitionInfo[] =
45.0, // rotation
M_SQRT2, // scaling
M_SQRT2, // scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -340,7 +340,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -353,7 +353,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_Y,
+ TransitionInfo::ReverseMethod::FlipY,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -365,7 +365,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -376,7 +376,7 @@ static const TransitionInfo lcl_transitionInfo[] =
180.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_Y,
+ TransitionInfo::ReverseMethod::FlipY,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -387,7 +387,7 @@ static const TransitionInfo lcl_transitionInfo[] =
-90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -401,7 +401,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -413,7 +413,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -425,7 +425,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -437,7 +437,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -450,7 +450,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -462,7 +462,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_Y,
+ TransitionInfo::ReverseMethod::FlipY,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -474,7 +474,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -486,7 +486,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -499,7 +499,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -511,7 +511,7 @@ static const TransitionInfo lcl_transitionInfo[] =
45.0, // rotation
M_SQRT2, // scaling
M_SQRT2, // scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -525,7 +525,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -537,7 +537,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -549,7 +549,7 @@ static const TransitionInfo lcl_transitionInfo[] =
180.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -561,7 +561,7 @@ static const TransitionInfo lcl_transitionInfo[] =
270.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -574,7 +574,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -586,7 +586,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -598,7 +598,7 @@ static const TransitionInfo lcl_transitionInfo[] =
180.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -610,7 +610,7 @@ static const TransitionInfo lcl_transitionInfo[] =
270.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -623,7 +623,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -635,7 +635,7 @@ static const TransitionInfo lcl_transitionInfo[] =
180.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -648,7 +648,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -660,7 +660,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -673,7 +673,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
true // scale isotrophically to target size
},
@@ -685,7 +685,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -697,7 +697,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
true // scale isotrophically to target size
},
@@ -711,7 +711,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -723,7 +723,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -735,7 +735,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -747,7 +747,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -760,7 +760,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -772,7 +772,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -784,7 +784,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT,
+ TransitionInfo::ReverseMethod::SubtractAndInvert,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -797,7 +797,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -809,7 +809,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_IGNORE,
+ TransitionInfo::ReverseMethod::Ignore,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -822,7 +822,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -834,7 +834,7 @@ static const TransitionInfo lcl_transitionInfo[] =
90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_ROTATE_180,
+ TransitionInfo::ReverseMethod::Rotate180,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -846,7 +846,7 @@ static const TransitionInfo lcl_transitionInfo[] =
180.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_ROTATE_180,
+ TransitionInfo::ReverseMethod::Rotate180,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -858,7 +858,7 @@ static const TransitionInfo lcl_transitionInfo[] =
270.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_ROTATE_180,
+ TransitionInfo::ReverseMethod::Rotate180,
true, // 'out' by parameter sweep inversion
false // scale isotrophically to target size
},
@@ -871,7 +871,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
true // scale isotrophically to target size, like ppt
},
@@ -883,7 +883,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
true // scale isotrophically to target size, like ppt
},
@@ -895,7 +895,7 @@ static const TransitionInfo lcl_transitionInfo[] =
-90.0, // rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_Y,
+ TransitionInfo::ReverseMethod::FlipY,
true, // 'out' by parameter sweep inversion
true // scale isotrophically to target size, like ppt
},
@@ -907,7 +907,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
true // scale isotrophically to target size, like ppt
},
@@ -919,7 +919,7 @@ static const TransitionInfo lcl_transitionInfo[] =
0.0, // no rotation
1.0, // no scaling
1.0, // no scaling
- TransitionInfo::REVERSEMETHOD_FLIP_X,
+ TransitionInfo::ReverseMethod::FlipX,
true, // 'out' by parameter sweep inversion
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list
diff --git a/slideshow/source/engine/transitions/clippingfunctor.cxx b/slideshow/source/engine/transitions/clippingfunctor.cxx
index c2e8fac..b7e9384 100644
--- a/slideshow/source/engine/transitions/clippingfunctor.cxx
+++ b/slideshow/source/engine/transitions/clippingfunctor.cxx
@@ -65,8 +65,8 @@ namespace slideshow
// perform general transformations _before_ the reverse
// mode changes. This allows the Transition table to be
// filled more consistently (otherwise, when e.g. rotating
// a clip 90 degrees, the REVERSEMETHOD_FLIP_X becomes
// REVERSEMETHOD_FLIP_Y instead)
if (rTransitionInfo.mnRotationAngle != 0.0 ||
rTransitionInfo.mnScaleX != 1.0 ||
rTransitionInfo.mnScaleY != 1.0)
@@ -101,34 +101,26 @@ namespace slideshow
"TransitionFactory::TransitionFactory(): Unexpected reverse method" );
break;
- case TransitionInfo::REVERSEMETHOD_IGNORE:
+ case TransitionInfo::ReverseMethod::Ignore:
break;
- case TransitionInfo::REVERSEMETHOD_INVERT_SWEEP:
- mbForwardParameterSweep = !mbForwardParameterSweep;
- break;
-
- case TransitionInfo::REVERSEMETHOD_SUBTRACT_POLYGON:
- mbSubtractPolygon = !mbSubtractPolygon;
- break;
-
- case TransitionInfo::REVERSEMETHOD_SUBTRACT_AND_INVERT:
+ case TransitionInfo::ReverseMethod::SubtractAndInvert:
mbForwardParameterSweep = !mbForwardParameterSweep;
mbSubtractPolygon = !mbSubtractPolygon;
break;
- case TransitionInfo::REVERSEMETHOD_ROTATE_180:
+ case TransitionInfo::ReverseMethod::Rotate180:
maStaticTransformation = basegfx::tools::createRotateAroundPoint(0.5, 0.5, M_PI)
* maStaticTransformation;
break;
- case TransitionInfo::REVERSEMETHOD_FLIP_X:
+ case TransitionInfo::ReverseMethod::FlipX:
maStaticTransformation = basegfx::tools::createScaleTranslateB2DHomMatrix(-1.0, 1.0, 1.0, 0.0)
* maStaticTransformation;
mbFlip = true;
break;
- case TransitionInfo::REVERSEMETHOD_FLIP_Y:
+ case TransitionInfo::ReverseMethod::FlipY:
maStaticTransformation = basegfx::tools::createScaleTranslateB2DHomMatrix(1.0, -1.0, 0.0, 1.0)
* maStaticTransformation;
mbFlip = true;
@@ -65,8 +65,8 @@ namespace slideshow
// mode changes. This allows the Transition table to be
// filled more consistently (otherwise, when e.g. rotating
- // a clip 90 degrees, the REVERSEMETHOD_FLIP_X becomes
- // REVERSEMETHOD_FLIP_Y instead)
+ // a clip 90 degrees, the ReverseMethod::FlipX becomes
+ // ReverseMethod::FlipY instead)
if (rTransitionInfo.mnRotationAngle != 0.0 ||
rTransitionInfo.mnScaleX != 1.0 ||